#!/usr/bin/env node
'use strict'

const readline = require("readline")
const fs = require("fs")
const path = require("path")
const chalk = require("chalk")
/**
 * argv = ["node","road"]
 */

let transform = require('./src/transform/icba')
const args = process.argv.splice(2)
let cache = path.join(process.cwd(), "cache")

if (args.includes("--bing")) {
    args.splice(args.indexOf("--bing"), 1)
    transform = require('./src/transform/bing')
}
if (args.includes("--icba")) {
    args.splice(args.indexOf("--icba"), 1)
    transform = require('./src/transform/icba')
}

if (args.includes("--clean")) {
    args.splice(args.indexOf("--clean"), 1)
    let dir = fs.readdirSync(cache)

    if (dir.length === 0) {
        console.log("no cache")
        if (args.length === 0) {
            process.exit()
        }
    } else {
        let rl = readline.createInterface({
            input: process.stdin,
            output: process.stdout
        })
        rl.question(chalk.red(`cached ${dir.length} files, clean(y/yes, n/no)? `), (ans) => {
            if (ans === "yes" || ans === "y") {
                try {
                    dir.forEach(item => {
                        fs.unlinkSync(path.join(cache, item))
                    })
                } catch (error) {
                    console.log(error)
                    process.exit()
                } finally {
                    console.log(chalk.green("clean success !"))
                    if (args.length === 0) {
                        process.exit()
                    }
                }
            }
        })
    }
} else if (args.includes("--repl")) {
    args.splice(args.indexOf("--repl"), 1)
    let rl = readline.createInterface({
        input: process.stdin,
        output: process.stdout
    })
    args[0] && transform(args[0])

    // process.stdout.write("please input word > ")
    rl.on("line", async (data) => {
        data.trim() && await transform(data.trim())
        // process.stdout.write("please input word > ")
    })
} else {
    args.forEach(word => {
        transform(word)
    })
}
