'use strict'

const https = require("https")
const querystring = require("querystring")
const fs = require("fs")
const path = require("path")
const out = require("./out")

module.exports = function (word) {
    console.log("use bing transform")
    return new Promise((resolve, rej) => {
        try {
            let data = fs.readFileSync(path.join(process.cwd(), "cache/" + word + ".json"))
            if (data) {
                out(word, JSON.parse(data), true)
            }
            resolve()
        } catch (error) {
            let query
            if (/^[\u4e00-\u9fa5]$/.test(word)) {
                query = querystring.stringify({
                    from: "zh-CHS",
                    to: "en",
                    text: word
                })
            } else {
                query = querystring.stringify({
                    from: "en",
                    to: "zh-CN",
                    text: word
                })
            }
            const req = https.request({
                protocol: "https:",
                host: "cn.bing.com",
                path: "/ttranslationlookup",
                method: "post",
                headers: {
                    "content-type": "application/x-www-form-urlencoded",
                    "content-length": Buffer.byteLength(query)
                }
            }, (res) => {
                let content = ""
                res.on("data", (chunk) => {
                    content += chunk
                })
                res.on("end", () => {
                    let result = JSON.parse(content)
                    let translations = result.translations
                    if (translations && translations.length > 0) {
                        let r = {}
                        translations.forEach(item => {
                            let posTag = item.posTag.toLowerCase()
                            if (!r[posTag]) {
                                r[posTag] = []
                            }
                            r[posTag].push(item.displayTarget)
                        })
                        let rs = []
                        let keys = Object.keys(r)
                        keys.forEach(key => {
                            rs.push({
                                prop: key,
                                desc: r[key].join("; ")
                            })
                        })
                        out(word, rs, false)
                        resolve()
                    }
                })
            })
            req.write(query)
            req.end()
        }
    })
}
